# Generated by Django 3.2.5 on 2022-03-31 22:34

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('chit_chat', '0003_remove_room_members'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='room',
            name='members_temp',
        ),
        migrations.AddField(
            model_name='room',
            name='members',
            field=models.ManyToManyField(related_name='chat_rooms', through='chit_chat.RoomMembership', to=settings.AUTH_USER_MODEL),
        ),
    ]
